"""add performance indexes

Revision ID: 71d546ace0ee
Revises: 0c05b22194f3
Create Date: 2025-09-12 16:07:53.775943

"""

from alembic import op
import sqlalchemy as sa
import sqlalchemy_utils


# revision identifiers, used by Alembic.
revision = "71d546ace0ee"
down_revision = "0c05b22194f3"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table("task", schema=None) as batch_op:
        batch_op.create_index(
            "ix_task_entity_project", ["entity_id", "project_id"], unique=False
        )

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table("task", schema=None) as batch_op:
        batch_op.drop_index("ix_task_entity_project")
    # ### end Alembic commands ###
